summaryrefslogtreecommitdiffstats
path: root/src/H5Tpublic.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2003-09-02 15:04:36 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2003-09-02 15:04:36 (GMT)
commit32a666f65243a0583be867935b892dd4ae13d1f4 (patch)
tree0378b28295a0eb21d6199ae84d4d023646d44fa2 /src/H5Tpublic.h
parent38d6179b319519ece95e6af9da1720cd63b0e4ac (diff)
downloadhdf5-32a666f65243a0583be867935b892dd4ae13d1f4.zip
hdf5-32a666f65243a0583be867935b892dd4ae13d1f4.tar.gz
hdf5-32a666f65243a0583be867935b892dd4ae13d1f4.tar.bz2
[svn-r7438] Purpose:
Code cleanup Description: More de-linting... Platforms tested: FreeBSD 4.9 (sleipnir) too small to need h5committest
Diffstat (limited to 'src/H5Tpublic.h')
-rw-r--r--src/H5Tpublic.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/H5Tpublic.h b/src/H5Tpublic.h
index 6842b63..1c0084e 100644
--- a/src/H5Tpublic.h
+++ b/src/H5Tpublic.h
@@ -24,7 +24,7 @@
#define HOFFSET(S,M) (offsetof(S,M))
-/* These are the various classes of data types */
+/* These are the various classes of datatypes */
/* If this goes over 16 types (0-15), the file format will need to change) */
typedef enum H5T_class_t {
H5T_NO_CLASS = -1, /*error */
@@ -134,7 +134,7 @@ typedef enum H5T_pad_t {
/* Commands sent to conversion functions */
typedef enum H5T_cmd_t {
H5T_CONV_INIT = 0, /*query and/or initialize private data */
- H5T_CONV_CONV = 1, /*convert data from source to dest data type */
+ H5T_CONV_CONV = 1, /*convert data from source to dest datatype */
H5T_CONV_FREE = 2 /*function is being removed from path */
} H5T_cmd_t;
@@ -181,15 +181,15 @@ typedef struct {
extern "C" {
#endif
/* All data type conversion functions are... */
typedef herr_t (*H5T_conv_t) (hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata,
hsize_t nelmts, size_t buf_stride, size_t bkg_stride, void *buf,
void *bkg, hid_t dset_xfer_plist);
/*
* If an error occurs during a data type conversion then the function
* registered with H5Tset_overflow() is called. It's arguments are the
- * source and destination data types, a buffer which has the source value,
+ * source and destination datatypes, a buffer which has the source value,
* and a buffer to receive an optional result for the overflow conversion.
* If the overflow handler chooses a value for the result it should return
* non-negative; otherwise the hdf5 library will choose an appropriate
@@ -468,7 +468,7 @@ H5_DLLVAR hid_t H5T_NATIVE_UINT_LEAST64_g;
H5_DLLVAR hid_t H5T_NATIVE_INT_FAST64_g;
H5_DLLVAR hid_t H5T_NATIVE_UINT_FAST64_g;
-/* Operations defined on all data types */
+/* Operations defined on all datatypes */
H5_DLL hid_t H5Topen(hid_t loc_id, const char *name);
H5_DLL hid_t H5Tcreate(H5T_class_t type, size_t size);
H5_DLL hid_t H5Tcopy(hid_t type_id);
@@ -478,12 +478,12 @@ H5_DLL herr_t H5Tlock(hid_t type_id);
H5_DLL herr_t H5Tcommit(hid_t loc_id, const char *name, hid_t type_id);
H5_DLL htri_t H5Tcommitted(hid_t type_id);
-/* Operations defined on compound data types */
+/* Operations defined on compound datatypes */
H5_DLL herr_t H5Tinsert(hid_t parent_id, const char *name, size_t offset,
hid_t member_id);
H5_DLL herr_t H5Tpack(hid_t type_id);
-/* Operations defined on enumeration data types */
+/* Operations defined on enumeration datatypes */
H5_DLL hid_t H5Tenum_create(hid_t base_id);
H5_DLL herr_t H5Tenum_insert(hid_t type, const char *name, void *value);
H5_DLL herr_t H5Tenum_nameof(hid_t type, void *value, char *name/*out*/,
@@ -491,16 +491,16 @@ H5_DLL herr_t H5Tenum_nameof(hid_t type, void *value, char *name/*out*/,
H5_DLL herr_t H5Tenum_valueof(hid_t type, const char *name,
void *value/*out*/);
-/* Operations defined on variable-length data types */
+/* Operations defined on variable-length datatypes */
H5_DLL hid_t H5Tvlen_create(hid_t base_id);
-/* Operations defined on array data types */
+/* Operations defined on array datatypes */
H5_DLL hid_t H5Tarray_create(hid_t base_id, int ndims,
const hsize_t dim[/* ndims */], const int perm[/* ndims */]);
H5_DLL int H5Tget_array_ndims(hid_t type_id);
H5_DLL int H5Tget_array_dims(hid_t type_id, hsize_t dims[], int perm[]);
-/* Operations defined on opaque data types */
+/* Operations defined on opaque datatypes */
H5_DLL herr_t H5Tset_tag(hid_t type, const char *tag);
H5_DLL char *H5Tget_tag(hid_t type);
@@ -181,15 +181,15 @@ typedef struct {
extern "C" {
#endif
-/* All data type conversion functions are... */
+/* All datatype conversion functions are... */
typedef herr_t (*H5T_conv_t) (hid_t src_id, hid_t dst_id, H5T_cdata_t *cdata,
hsize_t nelmts, size_t buf_stride, size_t bkg_stride, void *buf,
@@ -181,15 +181,15 @@ typedef struct {
void *bkg, hid_t dset_xfer_plist);
/*
- * If an error occurs during a data type conversion then the function
+ * If an error occurs during a datatype conversion then the function
* registered with H5Tset_overflow() is called. It's arguments are the